@@ -1,5 +1,5 @@
 <?php
-/* $Id: belarusian_cyrillic-utf-8.inc.php,v 1.49.2.3 2006/03/23 17:42:10 lem9 Exp $ */
+/* $Id: belarusian_cyrillic-utf-8.inc.php,v 1.74.2.1 2006/08/12 20:24:34 lem9 Exp $ */
 
 /**
  *     Translated by:
@@ -9,13 +9,12 @@
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
+$allow_recoding = TRUE;
 $text_dir = 'ltr';
-$left_font_family = 'verdana, tahoma, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'verdana, tahoma, arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits = array('Б', 'КБ', 'МБ', 'ГБ', 'ТБ', 'ПБ', 'ЭБ');
+$byteUnits = array('Б', 'КiБ', 'МіБ', 'ГіБ', 'ТіБ', 'ПіБ', 'ЭіБ');
 
 $day_of_week = array('Ндз', 'Пан', 'Аўт', 'Сер', 'Цач', 'Пят', 'Суб');
 $month = array('Сту', 'Лют', 'Сак', 'Кра', 'Тра', 'Чэр', 'Ліп', 'Жні', 'Вер', 'Кас', 'Ліс', 'Сьн');
@@ -31,15 +30,14 @@ $strAccessDeniedExplanation = 'phpMyAdmin паспрабаваў падлучы
 $strAccessDenied = 'У доступе адмоўлена';
 $strAction = 'Дзеяньне';
 $strAddAutoIncrement = 'Дадаць значэньне AUTO_INCREMENT';
+$strAddClause = 'Дадаць %s';
 $strAddConstraints = 'Дадаць абмежаваньні';
 $strAddDeleteColumn = 'Дадаць/выдаліць калёнку крытэру';
 $strAddDeleteRow = 'Дадаць/выдаліць радок крытэру';
-$strAddDropDatabase = 'Дадаць DROP DATABASE';
 $strAddedColumnComment = 'Даданы камэнтар да калёнкі';
 $strAddedColumnRelation = 'Даданая сувязь для калёнкі';
 $strAddFields = 'Дадаць новыя палі';
 $strAddHeaderComment = 'Дадаць прыватны камэнтар у загаловак (\\n падзяляе радкі)';
-$strAddIfNotExists = 'Дадаць IF NOT EXISTS';
 $strAddIntoComments = 'Дадаць у камэнтары';
 $strAddNewField = 'Дадаць новае поле';
 $strAddPrivilegesOnDb = 'Дадаць прывілеі на наступную базу';
@@ -114,6 +112,7 @@ $strBzError = 'phpMyAdmin ня можа сьціснуць дамп з-за пр
 $strBzip = 'сьціскаць у bzip';
 
 $strCalendar = 'Каляндар';
+$strCanNotLoadExportPlugins = 'Немагчыма загрузіць плагіны экспартаваньня, калі ласка, праверце ўсталяваныя файлы!';
 $strCanNotLoadImportPlugins = 'Немагчыма загрузіць плагіны імпартаваньня, калі ласка, праверце ўсталёўку!';
 $strCannotLogin = 'Немагчыма залагавацца на сэрвэр MySQL';
 $strCantLoad = 'немагчыма загрузіць пашырэньне %s;<br />калі ласка, праверце канфігурацыю PHP';
@@ -176,6 +175,10 @@ $strCreateNewTable = 'Стварыць новую табліцу ў БД %s';
 $strCreate = 'Стварыць';
 $strCreatePage = 'Стварыць новую старонку';
 $strCreatePdfFeat = 'Стварэньне PDF-файлаў';
+$strCreateUserDatabase = 'База дадзеных для карыстальніка';
+$strCreateUserDatabaseName = 'Стварыць базу дадзеных з такім самым імем і надзяліць усімі прывілеямі';
+$strCreateUserDatabaseNone = 'Ніякая';
+$strCreateUserDatabaseWildcard = 'Надзяліць усімі прывілеямі базы з іменамі па масцы (імя карыстальніка_%)';
 $strCreationDates = 'Стварэньне/Абнаўленьне/Праверка дат';
 $strCriteria = 'Крытэр';
 $strCroatian = 'Харвацкая';
@@ -228,6 +231,7 @@ $strDeleted = 'Радок быў выдалены';
 $strDeletedRows = 'Выдаленыя радкі:';
 $strDeleteNoUsersSelected = 'На выбраныя карыстальнікі для выдаленьня!';
 $strDeleting = 'Выдаленьне %s';
+$strDelimiter = 'Разьдзяляльнік';
 $strDelOld = 'Бягучая старонка ўтрымлівае спасылкі на табліцы, якія больш не існуюць. Ці жадаеце вы выдаліць гэтыя спасылкі?';
 $strDescending = 'адваротны';
 $strDescription = 'Апісаньне';
@@ -268,6 +272,7 @@ $strEnglish = 'Ангельская';
 $strEnglishPrivileges = ' Заўвага: імёны прывілеяў MySQL задаюцца па-ангельску ';
 $strError = 'Памылка';
 $strErrorInZipFile = 'Памылка ў ZIP-архіве:';
+$strErrorRenamingTable = 'Памылка перайменаваньня табліцы %1$s у %2$s';
 $strEscapeWildcards = 'Сымбалі падстаноўкі _ і % мусяць быць экранаванымі сымбалем \ для іх літаральнага выкарыстаньня';
 $strEsperanto = 'Эспэранта';
 $strEstonian = 'Эстонская';
@@ -275,6 +280,7 @@ $strExcelEdition = 'Вэрсія Excel';
 $strExcelOptions = 'Опцыі Excel';
 $strExecuteBookmarked = 'Выканаць запыт з закладак';
 $strExplain = 'Тлумачыць SQL';
+$strExportMustBeFile = 'Дадзеныя выбранага тыпу экспартаваньня мусяць быць зазаванымі ў файл!';
 $strExport = 'Экспарт';
 $strExtendedInserts = 'Пашыраныя ўстаўкі';
 $strExtra = 'Дадаткова';
@@ -301,11 +307,13 @@ $strFlushPrivilegesNote = 'Заўвага: phpMyAdmin атрымлівае пр
 $strFlushQueryCache = 'Скінуць кэш запытаў';
 $strFlushTable = 'Скінуць кэш табліцы ("FLUSH")';
 $strFlushTables = 'Скінуць (закрыць) усе табліцы';
+$strFontSize = 'Памер шрыфта';
 $strFormat = 'Фармат';
 $strFormEmpty = 'Не зададзенае значэньне ў форме!';
 $strFreePages = 'Вольных старонак';
 $strFullText = 'Поўныя тэксты';
 $strFunction = 'Функцыя';
+$strFunctions = 'Функцыі';
 
 $strGenBy = 'Створаны';
 $strGeneralRelationFeat = 'Магчымасьці асноўных сувязяў';
@@ -359,7 +367,7 @@ $strIndexWarningMultiple = 'Больш за адзін %s ключ быў ств
 $strIndexWarningPrimary = 'Абодва ключы PRIMARY і INDEX павінны быць вызначаны для калёнкі `%s`';
 $strIndexWarningTable = 'Праблемы з індэксамі для табліцы `%s`';
 $strIndexWarningUnique = 'Абодва ключы UNIQUE і INDEX павінны быць вызначаны для калёнкі `%s`';
-$strInnoDBAutoextendIncrement = 'Аўтапашыральнае прыпашчэньне';
+$strInnoDBAutoextendIncrement = 'Аўтапашыральнае прырашчэньне';
 $strInnoDBAutoextendIncrementDesc = ' Памер прырашчэньня для пашырэньня памеру прасторы аўтапашыральнай табліцы, калі яна запоўніцца.';
 $strInnoDBBufferPoolSizeDesc = 'Памер буфэру ў памяці, які InnoDB выкарыстоўвае для кэшаваньня дадзеных і індэксаў табліц.';
 $strInnoDBBufferPoolSize = 'Памер пулу буфэру';
@@ -372,7 +380,6 @@ $strInsecureMySQL = 'Ваш канфігурацыйны файл утрымлі
 $strInsertAsNewRow = 'Уставіць як новы радок';
 $strInsertedRowId = 'Id устаўленага радка:';
 $strInsertedRows = 'Даданыя радкі:';
-$strInsertNewRow = 'Уставіць новы радок';
 $strInsert = 'Уставіць';
 $strInternalNotNecessary = '* Унутраная сувязь не зьяўляецца абавязковай, калі яна ўжо існуе ў InnoDB.';
 $strInternalRelations = 'Унутраныя сувязі';
@@ -383,12 +390,14 @@ $strInvalidColumnCount = 'Колькасьць калёнак мусіць бы
 $strInvalidCSVFieldCount = 'Няправільная колькасьць палёў у CSV-дадзеных у радку %d.';
 $strInvalidCSVFormat = 'Некарэктны фармат CSV-дадзеных у радку %d.';
 $strInvalidCSVParameter = 'Недапушчальны парэмэтар для імпарту дадзеных у CSV: %s';
+$strInvalidDatabase = 'Няправільная база дадзеных';
 $strInvalidFieldAddCount = 'Трэба дадаць прынамсі адно поле.';
 $strInvalidFieldCount = 'Табліца мусіць мець прынамсі адно поле.';
 $strInvalidLDIImport = 'Гэты плагін не падтрымлівае сьціснутыя дадзеныя!';
 $strInvalidRowNumber = '%d не зьяўляецца карэктным нумарам радка.';
 $strInvalidServerHostname = 'Няправільнае імя хосту для сэрвэра %1$s. Калі ласка, праверце канфігурыцыю.';
 $strInvalidServerIndex = 'Некарэктны індэкс сэрвэра: "%s"';
+$strInvalidTableName = 'Некарэктнае імя табліцы';
 
 $strJapanese = 'Японская';
 $strJoins = 'Аб\'яднаньні';
@@ -404,6 +413,7 @@ $strKorean = 'Карэйская';
 
 $strLandscape = 'Краявід';
 $strLanguageFileNotFound = 'Моўны файл "%1$s" ня знойдзены.';
+$strLanguage = 'Мова';
 $strLanguageUnknown = 'Невядомая мова: %1$s.';
 $strLatchedPages = 'Фіксаваныя старонкі';
 $strLatexCaption = 'Загаловак табліцы';
@@ -483,6 +493,7 @@ $strNext = 'Наступны';
 $strNoActivity = 'Не было аніякай актыўнасьці на працягу %s сэкундаў. Калі ласка, увайдзіце зноў';
 $strNoDatabases = 'Базы дадзеных адсутнічаюць';
 $strNoDatabasesSelected = 'Ня выбраная база дадзеных.';
+$strNoDataReceived = 'Дадзеныя для імпартаваньня не атрыманыя. Альбо ніводны файл ня быў загружаны, альбо памер файла перавысіў максымальны памер, вызначаны канфігурацыяй PHP. Гл. FAQ 1.16.';
 $strNoDescription = 'няма апісаньня';
 $strNoDetailsForEngine = 'Для гэтай машыны захаваньня дадзеных дэтальная інфармацыя не даступная.';
 $strNoDropDatabases = 'Каманды "DROP DATABASE" адключаныя.';
@@ -504,7 +515,6 @@ $strNoRowsSelected = 'Ніводны радок ня выбраны';
 $strNoSpace = 'Недастаткова месца для захаваньня ў файл %s.';
 $strNoTablesFound = 'У базе дадзеных табліц ня выяўлена.';
 $strNoThemeSupport = 'Тэмы не падтрымліваюцца; калі ласка, праверце вашую канфігурацыю і/або вашыя тэмы ў тэчцы %s.';
-$strNothingToImport = 'Дадзеныя для імпартаваньня ня ўведзеныя!';
 $strNotNumber = 'Гэта ня лік!';
 $strNotOK = 'не OK';
 $strNotSet = 'Табліца <b>%s</b> ня знойдзеная або ня вызначаная ў %s';
@@ -517,6 +527,10 @@ $strNumSearchResultsTotal = '<b>Агулам:</b> <i>%s</i> супадзеньн
 $strNumTables = 'Табліц';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheet = 'Спэцыфікацыя Open Document';
+$strOpenDocumentSpreadsheetOptions = 'Опцыі спэцыфікацыі Open Document';
+$strOpenDocumentTextOptions = 'Опцыі тэксту Open Document';
+$strOpenDocumentText = 'Тэкст Open Document';
 $strOpenNewWindow = 'Адкрыць новае акно phpMyAdmin';
 $strOperations = 'Апэрацыі';
 $strOperator = 'Апэратар';
@@ -540,6 +554,7 @@ $strPdfInvalidTblName = 'Табліцы "%s" не існуе!';
 $strPdfNoTables = 'Няма табліц';
 $strPDFOptions = 'Парамэтры PDF';
 $strPDF = 'PDF';
+$strPDFReportExplanation = '(Генэруе справаздачу з дадзенымі асобнай табліцы)';
 $strPDFReportTitle = 'Загаловак справаздачы';
 $strPerHour = 'у гадзіну';
 $strPerMinute = 'у хвіліну';
@@ -600,6 +615,8 @@ $strPrivDescUpdate = 'Дазваляе зьмяняць дадзеныя.';
 $strPrivDescUsage = 'Без прывілеяў.';
 $strPrivileges = 'Прывілеі';
 $strPrivilegesReloaded = 'Прывілеі былі пасьпяхова перазагружаныя.';
+$strProcedures = 'Працэдуры';
+$strProcesses = 'Працэсы';
 $strProcesslist = 'Сьпіс працэсаў';
 $strProtocolVersion = 'Вэрсія пратаколу';
 $strPutColNames = 'Пазначыць назвы палёў у першым радку';
@@ -610,6 +627,7 @@ $strQBEIns = 'Уставіць';
 $strQueryCache = 'Кэш запытаў';
 $strQueryFrame = 'Акно запыту';
 $strQueryOnDb = 'SQL-запыт да БД <b>%s</b>:';
+$strQueryResultsOperations = 'Дзеяньні з вынікамі запытаў';
 $strQuerySQLHistory = 'Гісторыя SQL';
 $strQueryStatistics = '<b>Статыстыка запытаў</b>: З моманту запуску %s запытаў было адпраўлена на сэрвэр.';
 $strQueryTime = 'Запыт выконваўся %01.4f сэк';
@@ -627,7 +645,7 @@ $strRelationsForTable = 'Сувязі ў табліцы';
 $strRelations = 'Сувязі';
 $strRelationView = 'Прагляд залежнасьцяў';
 $strReloadingThePrivileges = 'Перазагрузіць прывілеі';
-$strReloadMySQL = 'Перазагрузіць MySQL';
+$strReloadPrivileges = 'Перазагрузіць прывілеі';
 $strRemoveSelectedUsers = 'Выдаліць выбраных карыстальнікаў';
 $strRenameDatabaseOK = 'База дадзеных %s была перайменаваная ў %s';
 $strRenameTable = 'Перайменаваць табліцу ў';
@@ -684,10 +702,10 @@ $strSent = 'Адпраўлена';
 $strServerChoice = 'Выбар сэрвэра';
 $strServerNotResponding = 'Сэрвэр не адказвае';
 $strServer = 'Сэрвэр';
+$strServers = 'Сэрвэры';
 $strServerStatus = 'Бягучая інфармацыя';
 $strServerStatusDelayedInserts = 'Адкладзеныя ўстаўкі';
 $strServerStatusUptime = 'Гэты сэрвэр MySQL працуе %s. Ён быў запушчаны %s.';
-$strServerTabProcesslist = 'Працэсы';
 $strServerTabVariables = 'Зьменныя';
 $strServerTrafficNotes = '<b>Трафік сэрвэра</b>: Гэтыя табліцы паказваюць статыстыку сеткавага трафіку гэтага сэрвэра MySQL ад моманту ягонага запуску.';
 $strServerVars = 'Налады і зьменныя сэрвэра';
@@ -829,7 +847,7 @@ $strSorting = 'Сартаваньне';
 $strSpaceUsage = 'Выкарыстаньне прасторы';
 $strSpanish = 'Гішпанская';
 $strSplitWordsWithSpace = 'Словы падзеленыя прагалам (" ").';
-$strSQLExportCompatibility = 'Сумяшчальнасьць экспартаванага SQL';
+$strSQLCompatibility = 'Рэжым сумяшчальнасьці SQL';
 $strSQLExportType = 'Тып экспарту';
 $strSQLImportOptions = 'Парамэтры SQL';
 $strSQLOptions = 'Опцыі SQL';
@@ -851,9 +869,9 @@ $strStorageEngine = 'Машына захаваньня дадзеных';
 $strStorageEngines = 'Машыны захаваньня дадзеных';
 $strStrucCSV = 'CSV';
 $strStrucData = 'Структуру і дадзеныя';
-$strStrucDrop = 'Дадаць выдаленьне табліцы';
 $strStrucExcelCSV = 'CSV для дадзеных MS Excel';
 $strStrucNativeExcel = 'Родны фармат MS Excel';
+$strStrucNativeExcelOptions = 'Стандартныя опцыі экспартаваньня ў Excel';
 $strStrucOnly = 'Толькі структуру';
 $strStructPropose = 'Прапанаваная структура табліцы';
 $strStructure = 'Структура';
@@ -876,7 +894,6 @@ $strTableOfContents = 'Зьмест';
 $strTableOptions = 'Опцыі табліцы';
 $strTables = '%s табліц(ы)';
 $strTableStructure = 'Структура табліцы';
-$strTableType = 'Тып табліцы';
 $strTakeIt = 'гэтая';
 $strTblPrivileges = 'Прывілеі, спэцыфічныя для табліцы';
 $strTempData = 'Часовыя дадзеныя';
@@ -904,7 +921,7 @@ $strTraditionalSpanish = 'Традыцыйная гішпанская';
 $strTraffic = 'Трафік';
 $strTransactionCoordinator = 'Каардынатар перакладу';
 $strTransformation_application_octetstream__download = 'Паказвае спасылку для загрузкі двойкавых дадзеных поля. Вы можаце выкарыстоўваць першую опцыю для вызначэньня імя файла або выкарыстоўвайце другую опцыю як імя поля, якое ўтрымлівае імя файла. Калі вы выкарыстоўваеце другую опцыю, вам трэба пакінуць першае поле пустым';
-$strTransformation_application_octetstream__hex = 'Паказвае дадзеныя ў шаснаццаткавым выглядзе.';
+$strTransformation_application_octetstream__hex = 'Паказвае дадзеныя ў шаснаццаткавым выглядзе. Апцыянальны першы парамэтар вызначае частату дадаваньня прагала (па-змоўчаньні — праз кожныя 8 бітаў).';
 $strTransformation_image_jpeg__inline = 'Паказвае націскальны эскіз; Опцыі — максымальная шырыня і вышыня ў піксэлах. Захоўваюцца пачатковыя прапорцыі.';
 $strTransformation_image_jpeg__link = 'Паказвае спасылку для загрузкі гэтага малюнку.';
 $strTransformation_image_png__inline = 'Праглядзець малюнак image/jpeg: убудаваны';
@@ -932,6 +949,7 @@ $strUpdateQuery = 'Абнавіць запыт';
 $strUpdComTab = 'За інфармацыяй як абнавіць табліцу column_comments зьвярніцеся, калі ласка, да дакумэнтацыі';
 $strUpgrade = 'Вам трэба абнавіць %s да вэрсіі %s ці пазьнейшай.';
 $strUploadLimit = 'Вы, мусіць, паспрабавалі загрузіць вельмі вялікі файл. Калі ласка, зьвярніцеся да %sдакумэнтацыі%s для высьвятленьня спосабаў абыйсьці гэтае абмежаваньне.';
+$strUploadsNotAllowed = 'Загрузкі файлаў не дазволеныя на гэтым сэрвэры.';
 $strUsage = 'Выкарыстаньне';
 $strUseBackquotes = 'Зваротнае двукосьсе ў імёнах табліц і палёў';
 $strUsedPhpExtensions = 'Выкарыстоўваюцца пашырэньні PHP';
@@ -973,6 +991,7 @@ $strWritingCommentNotPossible = 'Немагчыма дадаць камэнта
 $strWritingRelationNotPossible = 'Немагчыма дадаць сувязь';
 $strWrongUser = 'Няправільны лагін/пароль. У доступе адмоўлена.';
 
+$strXMLOptions = 'Опцыі XML';
 $strXML = 'XML';
 
 $strYes = 'Так';
