@@ -1,14 +1,18 @@
 <?php
-/* $Id: english-iso-8859-1.inc.php,v 2.130.2.2 2006/02/17 12:42:59 lem9 Exp $ */
+/* $Id: english-iso-8859-1.inc.php,v 2.158.2.1 2006/08/30 10:43:14 nijel Exp $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
+$byteUnits = array('B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
+
+// MySQL manual language definition, this is optional, en will be used 
+// if not defined
+$mysql_4_1_doc_lang = 'en';
+$mysql_5_0_doc_lang = 'en';
+$mysql_5_1_doc_lang = 'en';
 
 $day_of_week = array('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');
 $month = array('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec');
@@ -24,15 +28,14 @@ $strAccessDeniedCreateConfig = 'Probably reason of this is that you did not crea
 $strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.';
 $strAction = 'Action';
 $strAddAutoIncrement = 'Add AUTO_INCREMENT value';
+$strAddClause = 'Add %s';
 $strAddConstraints = 'Add constraints';
 $strAddDeleteColumn = 'Add/Delete Field Columns';
 $strAddDeleteRow = 'Add/Delete Criteria Row';
-$strAddDropDatabase = 'Add DROP DATABASE';
 $strAddedColumnComment = 'Added comment for column';
 $strAddedColumnRelation = 'Added relation for column';
 $strAddFields = 'Add %s field(s)';
 $strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';
-$strAddIfNotExists = 'Add IF NOT EXISTS';
 $strAddIntoComments = 'Add into comments';
 $strAddNewField = 'Add new field';
 $strAddPrivilegesOnDb = 'Add privileges on the following database';
@@ -107,6 +110,7 @@ $strBzError = 'phpMyAdmin was unable to compress the dump because of a broken Bz
 $strBzip = '"bzipped"';
 
 $strCalendar = 'Calendar';
+$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';
 $strCannotLogin = 'Cannot log in to the MySQL server';
 $strCantLoad = 'Cannot load [a@http://php.net/%1$s@Documentation][em]%1$s[/em][/a] extension. Please check your PHP configuration.';
@@ -169,6 +173,10 @@ $strCreateNewDatabase = 'Create new database';
 $strCreateNewTable = 'Create new table on database %s';
 $strCreatePage = 'Create a new page';
 $strCreatePdfFeat = 'Creation of PDFs';
+$strCreateUserDatabase = 'Database for user';
+$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';
+$strCreateUserDatabaseNone = 'None';
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';
 $strCreationDates = 'Creation/Update/Check dates';
 $strCriteria = 'Criteria';
 $strCroatian = 'Croatian';
@@ -221,6 +229,7 @@ $strDeletedRows = 'Deleted rows:';
 $strDeleted = 'The row has been deleted';
 $strDeleteNoUsersSelected = 'No users selected for deleting!';
 $strDeleting = 'Deleting %s';
+$strDelimiter = 'Delimiter';
 $strDelOld = 'The current page has references to tables that no longer exist. Would you like to delete those references?';
 $strDescending = 'Descending';
 $strDescription = 'Description';
@@ -261,6 +270,7 @@ $strEnglish = 'English';
 $strEnglishPrivileges = ' Note: MySQL privilege names are expressed in English ';
 $strError = 'Error';
 $strErrorInZipFile = 'Error in ZIP archive:';
+$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';
 $strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonian';
@@ -269,6 +279,7 @@ $strExcelOptions = 'Excel options';
 $strExecuteBookmarked = 'Execute bookmarked query';
 $strExplain = 'Explain SQL';
 $strExport = 'Export';
+$strExportMustBeFile = 'Selected export type has to be saved in file!';
 $strExtendedInserts = 'Extended inserts';
 $strExtra = 'Extra';
 
@@ -294,11 +305,13 @@ $strFlushPrivilegesNote = 'Note: phpMyAdmin gets the users\' privileges directly
 $strFlushQueryCache = 'Flush query cache';
 $strFlushTable = 'Flush the table ("FLUSH")';
 $strFlushTables = 'Flush (close) all tables';
+$strFontSize = 'Font size';
 $strFormat = 'Format';
 $strFormEmpty = 'Missing value in the form!';
 $strFreePages = 'Free pages';
 $strFullText = 'Full Texts';
 $strFunction = 'Function';
+$strFunctions = 'Functions';
 
 $strGenBy = 'Generated by';
 $strGeneralRelationFeat = 'General relation features';
@@ -366,7 +379,6 @@ $strInsertAsNewRow = 'Insert as new row';
 $strInsertedRowId = 'Inserted row id:';
 $strInsertedRows = 'Inserted rows:';
 $strInsert = 'Insert';
-$strInsertNewRow = 'Insert new row';
 $strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.';
 $strInternalRelations = 'Internal relations';
 $strInUse = 'in use';
@@ -376,12 +388,14 @@ $strInvalidColumn = 'Invalid column (%s) specified!';
 $strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';
 $strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';
 $strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';
+$strInvalidDatabase = 'Invalid database';
 $strInvalidFieldAddCount = 'You have to add at least one field.';
 $strInvalidFieldCount = 'Table must have at least one field.';
 $strInvalidLDIImport = 'This plugin does not support compressed imports!';
 $strInvalidRowNumber = '%d is not valid row number.';
 $strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';
 $strInvalidServerIndex = 'Invalid server index: "%s"';
+$strInvalidTableName = 'Invalid table name';
 
 $strJapanese = 'Japanese';
 $strJoins = 'Joins';
@@ -397,6 +411,7 @@ $strKorean = 'Korean';
 
 $strLandscape = 'Landscape';
 $strLanguageFileNotFound = 'Language file "%1$s" not found.';
+$strLanguage = 'Language';
 $strLanguageUnknown = 'Unknown language: %1$s.';
 $strLatchedPages = 'Latched pages';
 $strLatexCaption = 'Table caption';
@@ -476,6 +491,7 @@ $strNext = 'Next';
 $strNoActivity = 'No activity within %s seconds; please log in again';
 $strNoDatabases = 'No databases';
 $strNoDatabasesSelected = 'No databases selected.';
+$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';
 $strNoDescription = 'no description';
 $strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';
 $strNoDropDatabases = '"DROP DATABASE" statements are disabled.';
@@ -497,7 +513,6 @@ $strNoRowsSelected = 'No rows selected';
 $strNoSpace = 'Insufficient space to save the file %s.';
 $strNoTablesFound = 'No tables found in database.';
 $strNoThemeSupport = 'No themes support; please check your configuration and/or your themes in directory %s.';
-$strNothingToImport = 'You didn\'t enter any data to import!';
 $strNotNumber = 'This is not a number!';
 $strNotOK = 'not OK';
 $strNotSet = '<b>%s</b> table not found or not set in %s';
@@ -510,6 +525,10 @@ $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> match(es)';
 $strNumTables = 'Tables';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';
+$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';
+$strOpenDocumentText = 'Open Document Text';
+$strOpenDocumentTextOptions = 'Open Document Text options';
 $strOpenNewWindow = 'Open new phpMyAdmin window';
 $strOperations = 'Operations';
 $strOperator = 'Operator';
@@ -533,6 +552,7 @@ $strPdfInvalidTblName = 'The "%s" table doesn\'t exist!';
 $strPdfNoTables = 'No tables';
 $strPDFOptions = 'PDF options';
 $strPDF = 'PDF';
+$strPDFReportExplanation = '(Generates a report containing the data of a single table)';
 $strPDFReportTitle = 'Report title';
 $strPerHour = 'per hour';
 $strPerMinute = 'per minute';
@@ -593,6 +613,8 @@ $strPrivDescUpdate = 'Allows changing data.';
 $strPrivDescUsage = 'No privileges.';
 $strPrivileges = 'Privileges';
 $strPrivilegesReloaded = 'The privileges were reloaded successfully.';
+$strProcedures = 'Procedures';
+$strProcesses = 'Processes';
 $strProcesslist = 'Process list';
 $strProtocolVersion = 'Protocol version';
 $strPutColNames = 'Put fields names in the first row';
@@ -603,6 +625,7 @@ $strQBE = 'Query';
 $strQueryCache = 'Query cache';
 $strQueryFrame = 'Query window';
 $strQueryOnDb = 'SQL query on database <b>%s</b>:';
+$strQueryResultsOperations = 'Query results operations';
 $strQuerySQLHistory = 'SQL history';
 $strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.';
 $strQueryTime = 'Query took %01.4f sec';
@@ -620,7 +643,7 @@ $strRelationsForTable = 'RELATIONS FOR TABLE';
 $strRelations = 'Relations';
 $strRelationView = 'Relation view';
 $strReloadingThePrivileges = 'Reloading the privileges';
-$strReloadMySQL = 'Reload MySQL';
+$strReloadPrivileges = 'Reload privileges';
 $strRemoveSelectedUsers = 'Remove selected users';
 $strRenameDatabaseOK = 'Database %s has been renamed to %s';
 $strRenameTableOK = 'Table %s has been renamed to %s';
@@ -677,10 +700,10 @@ $strSent = 'Sent';
 $strServerChoice = 'Server Choice';
 $strServerNotResponding = 'The server is not responding';
 $strServer = 'Server';
+$strServers = 'Servers';
 $strServerStatusDelayedInserts = 'Delayed inserts';
 $strServerStatus = 'Runtime Information';
 $strServerStatusUptime = 'This MySQL server has been running for %s. It started up on %s.';
-$strServerTabProcesslist = 'Processes';
 $strServerTabVariables = 'Variables';
 $strServerTrafficNotes = '<b>Server traffic</b>: These tables show the network traffic statistics of this MySQL server since its startup.';
 $strServerVars = 'Server variables and settings';
@@ -822,7 +845,7 @@ $strSort = 'Sort';
 $strSpaceUsage = 'Space usage';
 $strSpanish = 'Spanish';
 $strSplitWordsWithSpace = 'Words are separated by a space character (" ").';
-$strSQLExportCompatibility = 'SQL export compatibility';
+$strSQLCompatibility = 'SQL compatibility mode';
 $strSQLExportType = 'Export type';
 $strSQLImportOptions = 'SQL options';
 $strSQLOptions = 'SQL options';
@@ -844,9 +867,9 @@ $strStorageEngines = 'Storage Engines';
 $strStorageEngine = 'Storage Engine';
 $strStrucCSV = 'CSV';
 $strStrucData = 'Structure and data';
-$strStrucDrop = 'Add DROP TABLE';
 $strStrucExcelCSV = 'CSV for MS Excel';
 $strStrucNativeExcel = 'Native MS Excel format';
+$strStrucNativeExcelOptions = 'Native Excel export options';
 $strStrucOnly = 'Structure only';
 $strStructPropose = 'Propose table structure';
 $strStructure = 'Structure';
@@ -869,7 +892,6 @@ $strTableOptions = 'Table options';
 $strTables = '%s table(s)';
 $strTableStructure = 'Table structure for table';
 $strTable = 'Table';
-$strTableType = 'Table type';
 $strTakeIt = 'take it';
 $strTblPrivileges = 'Table-specific privileges';
 $strTempData = 'Temporary data';
@@ -897,7 +919,7 @@ $strTraditionalSpanish = 'Traditional Spanish';
 $strTraffic = 'Traffic';
 $strTransactionCoordinator = 'Transaction coordinator';
 $strTransformation_application_octetstream__download = 'Displays a link to download the binary data of the field. You can use the first option to specify the filename, or use the second option as the name of a field which contains the filename. If you use the second option, you need to set the first option to the empty string.';
-$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';
 $strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail. The options are the maximum width and height in pixels. The original aspect ratio is preserved.';
 $strTransformation_image_jpeg__link = 'Displays a link to download this image.';
 $strTransformation_image_png__inline = 'See image/jpeg: inline';
@@ -925,6 +947,7 @@ $strUpdateQuery = 'Update Query';
 $strUpdComTab = 'Please see the documentation on how to update your column_comments table';
 $strUpgrade = 'You should upgrade to %s %s or later.';
 $strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';
+$strUploadsNotAllowed = 'File uploads are not allowed on this server.';
 $strUsage = 'Usage';
 $strUseBackquotes = 'Enclose table and field names with backquotes';
 $strUsedPhpExtensions = 'Used PHP extensions';
@@ -966,6 +989,7 @@ $strWritingCommentNotPossible = 'Writing of comment not possible';
 $strWritingRelationNotPossible = 'Writing of relation not possible';
 $strWrongUser = 'Wrong username/password. Access denied.';
 
+$strXMLOptions = 'XML options';
 $strXML = 'XML';
 
 $strYes = 'Yes';
