@@ -1,19 +1,17 @@
 <?php
-/* $Id: norwegian-utf-8.inc.php,v 2.132 2006/01/29 12:40:50 lem9 Exp $ */
+/* $Id: norwegian-utf-8.inc.php,v 2.157.2.1 2006/08/26 14:00:37 lem9 Exp $ */
 
 /**
- * Translated by Sven-Erik Andersen <sven-erik.andersen at pkf107.no>
+ * Translated by Sven-Erik Andersen <sven DOT erik DOT andersen AT gmail DOT com>
  */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr';
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = '.';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
+$byteUnits = array('Bytes', 'B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
 
 $day_of_week = array('Søn', 'Man', 'Tir', 'Ons', 'Tor', 'Fre', 'Lør');
 $month = array('Jan', 'Feb', 'Mar', 'Apr', 'Mai', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Des');
@@ -29,15 +27,14 @@ $strAccessDeniedExplanation = 'phpMyAdmin forsøkte å koble til MySQL-serveren,
 $strAccessDenied = 'Ingen tilgang';
 $strAction = 'Handling';
 $strAddAutoIncrement = 'Legg til AUTO_INCREMENT verdi';
+$strAddClause = 'Legg til %s';
 $strAddConstraints = 'Legg til begrensninger';
 $strAddDeleteColumn = 'Legg til/Slett kolonne';
 $strAddDeleteRow = 'Legg til/Slett kriterierad';
-$strAddDropDatabase = 'Legg til DROP DATABASE';
 $strAddedColumnComment = 'Lagt til kolonnekommentar';
 $strAddedColumnRelation = 'Lagt til relasjon for kolonne';
 $strAddFields = 'Legg til %s felt(er)';
 $strAddHeaderComment = 'Legg til egen kommentar i hodet (\\n lager linjeskift)';
-$strAddIfNotExists = 'Legg til IF NOT EXISTS';
 $strAddIntoComments = 'Legg til i kommentarer';
 $strAddNewField = 'Legg til felt';
 $strAddPrivilegesOnDb = 'Legg til privilegier til følgende database';
@@ -112,6 +109,7 @@ $strBzError = 'phpMyAdmin kunne ikke komprimere dumpede data fordi Bz2 tillegget
 $strBzip = 'Komprimert (bz2)';
 
 $strCalendar = 'Kalender';
+$strCanNotLoadExportPlugins = 'Kunne ikke laste eksporttillegg, kontroller din innstallasjon!';
 $strCanNotLoadImportPlugins = 'Kan ikke starte importeringsprogramtilleggene, kontroller din installasjon!';
 $strCannotLogin = 'Kan ikke logge inn til MySQL tjeneren';
 $strCantLoad = 'Kan ikke starte %s tillegget,<br />vennligst kontroller PHP-konfigurasjonen';
@@ -174,7 +172,11 @@ $strCreateNewTable = 'Opprett ny tabell i database %s';
 $strCreate = 'Opprett';
 $strCreatePage = 'Lag en ny side';
 $strCreatePdfFeat = 'Lag PDF-dokumenter';
-$strCreationDates = 'Opprettelse/Oppdaterings/Kontrolldateo';
+$strCreateUserDatabase = 'Brukerdatabase';
+$strCreateUserDatabaseName = 'Opprett database med samme navn og gi alle rettigheter';
+$strCreateUserDatabaseNone = 'Ingen';
+$strCreateUserDatabaseWildcard = 'Gi alle rettigheter på jokertegnavn (username_%)';
+$strCreationDates = 'Opprettelse/Oppdaterings/Kontrolldato';
 $strCriteria = 'Kriterier';
 $strCroatian = 'kroatisk';
 $strCSV = 'CSV';
@@ -186,7 +188,7 @@ $strCzech = 'tjekkisk';
 
 $strDanish = 'dansk';
 $strDatabase = 'Database';
-$strDatabaseEmpty = 'Databasens navn er tomt!';
+$strDatabaseEmpty = 'Databasen er uten navn!';
 $strDatabaseExportOptions = 'Databaseeksportinnstillinger';
 $strDatabaseHasBeenDropped = 'Databasen %s har blitt slettet';
 $strDatabaseNoTable = 'Denne databasen har ingen tabeller!';
@@ -194,7 +196,7 @@ $strDatabases = 'databaser';
 $strDatabasesDropped = '%s databasene har blitt slettet.';
 $strDatabasesStatsDisable = 'Slå av statistikk';
 $strDatabasesStatsEnable = 'Slå på statistikk';
-$strDatabasesStatsHeavyTraffic = 'OBS: Når du slår på Databasestatistikk så kan det medføre stor traffik mellom webtjeneren og MySQL-tjeneren.';
+$strDatabasesStatsHeavyTraffic = 'OBS: Når du slår på databasestatistikk så kan det medføre stor traffik mellom webtjeneren og MySQL-tjeneren.';
 $strDatabasesStats = 'Statistikk for databaser';
 $strData = 'Data';
 $strDataDict = 'Dataordbok';
@@ -211,7 +213,7 @@ $strDBGMinTimeMs = 'Min tid, ms';
 $strDBGModule = 'Modul';
 $strDBGTimePerHitMs = 'Tid/Treff, ms';
 $strDBGTotalTimeMs = 'Total tid, ms';
-$strDbPrivileges = 'Database-spesifikke privilegier';
+$strDbPrivileges = 'Databasespesifikke privilegier';
 $strDBRename = 'Endre databasens navn til';
 $strDbSpecific = 'databasespesifikk';
 $strDefaultEngine = '%s er standard lagringsmotor for denne MySQL tjeneren.';
@@ -226,6 +228,7 @@ $strDeletedRows = 'Slettede rader:';
 $strDeleteNoUsersSelected = 'Ingen brukere merket for sletting!';
 $strDelete = 'Slett';
 $strDeleting = 'Sletter %s';
+$strDelimiter = 'Skilletegn';
 $strDelOld = 'Den nåværende siden har referanser til tabeller som ikke lenger eksisterer. Vil du slette disse referansene?';
 $strDescending = 'Synkende';
 $strDescription = 'Beskrivelse';
@@ -266,6 +269,7 @@ $strEnglish = 'engelsk';
 $strEnglishPrivileges = 'OBS: MySQL privilegiumnavn er på engelsk';
 $strError = 'Feil';
 $strErrorInZipFile = 'Feil i ZIP arkivet:';
+$strErrorRenamingTable = 'Feil oppstond med endring av tabellnavn fra %1$s til %2$s';
 $strEscapeWildcards = 'Jokertegnene _ og % må beskyttes med en \ for å bruke dem direkte';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'estisk';
@@ -274,6 +278,7 @@ $strExcelOptions = 'Excel-innstillinger';
 $strExecuteBookmarked = 'Utfør lagret spørring';
 $strExplain = 'Forklar SQL';
 $strExport = 'Eksporter';
+$strExportMustBeFile = 'Valgte eksporteringstype krever lagring til ei fil!';
 $strExtendedInserts = 'Utvidete innlegg';
 $strExtra = 'Ekstra';
 
@@ -299,11 +304,13 @@ $strFlushPrivilegesNote = 'Merk: phpMyAdmin får brukerprivilegiene direkte fra
 $strFlushQueryCache = 'Flush query cache';
 $strFlushTable = 'Oppfrisk tabellen ("FLUSH")';
 $strFlushTables = 'Flush (close) all tables';
+$strFontSize = 'Fontstørrelse';
 $strFormat = 'Format';
 $strFormEmpty = 'Manglende verdi i skjemaet!';
 $strFreePages = 'Ledige sider';
 $strFullText = 'Hele strenger';
 $strFunction = 'Funksjon';
+$strFunctions = 'Funsjoner';
 
 $strGenBy = 'Generert av';
 $strGeneralRelationFeat = 'Generelle relasjonsegenskaper';
@@ -370,7 +377,6 @@ $strInsecureMySQL = 'Din konfigurasjonsfil inneholder innstillinger (root uten p
 $strInsertAsNewRow = 'Sett inn som ny rad';
 $strInsertedRowId = 'Satt inn rad id:';
 $strInsertedRows = 'Innsatte rader:';
-$strInsertNewRow = 'Sett inn ny rad';
 $strInsert = 'Sett inn';
 $strInternalNotNecessary = '* En intern relasjon er ikke nødvendig når den også eksisterer i InnoDB.';
 $strInternalRelations = 'Interne relasjoner';
@@ -381,12 +387,14 @@ $strInvalidColumn = 'Ugyldig kollonne (%s) angitt!';
 $strInvalidCSVFieldCount = 'Ugyldig antall felt i CSV importen i linje %d.';
 $strInvalidCSVFormat = 'Ugyldig format i CSV importen i linje %d.';
 $strInvalidCSVParameter = 'Ugyldig parameter for CSV import: %s';
+$strInvalidDatabase = 'Ugylding database';
 $strInvalidFieldAddCount = 'Du må sette inn minst ett felt.';
 $strInvalidFieldCount = 'Tabellen må ha minst ett felt.';
 $strInvalidLDIImport = 'Dette tillegget støtter ikke komprimerte importeringer!';
 $strInvalidRowNumber = '%d er ikke et gyldig radnummer.';
 $strInvalidServerHostname = 'Ugyldig tjenernavn for tjener %1$s. Kontroller din konfigurasjon.';
 $strInvalidServerIndex = 'Ugyldig tjenerindeks: "%s"';
+$strInvalidTableName = 'Ugylding tabellnavn';
 
 $strJapanese = 'japansk';
 $strJoins = 'Sammenføyninger';
@@ -402,6 +410,7 @@ $strKorean = 'koreansk';
 
 $strLandscape = 'Landskapsformat';
 $strLanguageFileNotFound = 'Språkfil "%1$s" ble ikke funnet.';
+$strLanguage = 'Språk';
 $strLanguageUnknown = 'Ukjent språk: %1$s.';
 $strLatchedPages = 'Tilknyttede sider';
 $strLatexCaption = 'Tabelloverskrift';
@@ -481,6 +490,7 @@ $strNext = 'Neste';
 $strNoActivity = 'Ingen aktivitet på %s sekunder eller mer, du må logge inn på nytt';
 $strNoDatabases = 'Ingen databaser';
 $strNoDatabasesSelected = 'Ingen databaser er valgt.';
+$strNoDataReceived = 'Ingen data ble mottatt for importering. Enten ble ingen filnavn gitt, eller filstørrelsen oversteg maksimum størrelse tillatt i din PHP konfigurasjon. Se FAQ 1.16';
 $strNoDescription = 'ingen beskrivelse';
 $strNoDetailsForEngine = 'Det er ikke noen detaljert statusinformasjon for denne lagringsmotoren.';
 $strNoDropDatabases = '"DROP DATABASE"-uttrykk er avslått.';
@@ -502,7 +512,6 @@ $strNoRowsSelected = 'Ingen rader valgt';
 $strNoSpace = 'Ikke nok plass til å lagre fila %s.';
 $strNoTablesFound = 'Ingen tabeller i databasen.';
 $strNoThemeSupport = 'Ikke støtte for maler, kontroller konfigureringen og/eller dine maler i katalogen %s.';
-$strNothingToImport = 'Du skrev ikke inn noe data for import!';
 $strNotNumber = 'Dette er ikke ett tall!';
 $strNotOK = 'ikke OK';
 $strNotSet = '<b>%s</b> tabellen ble ikke funnet eller ikke konfigurert i %s';
@@ -515,6 +524,10 @@ $strNumSearchResultsTotal = '<b>Totalt:</b> <i>%s</i> treff';
 $strNumTables = 'Tabeller';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheet = 'Open Document regneark';
+$strOpenDocumentSpreadsheetOptions = 'Open Document regnearkinnstillinger';
+$strOpenDocumentText = 'Open Document tekst';
+$strOpenDocumentTextOptions = 'Open Document tekstinnstillinger';
 $strOpenNewWindow = 'Åpne nytt phpMyAdmin vindu';
 $strOperations = 'Operasjoner';
 $strOperator = 'Operator';
@@ -538,6 +551,7 @@ $strPdfInvalidTblName = 'Tabellen "%s" eksisterer ikke!';
 $strPdfNoTables = 'Ingen tabeller';
 $strPDFOptions = 'PDF innstillinger';
 $strPDF = 'PDF';
+$strPDFReportExplanation = '(Oppretter en rapport som inneholder dataene fra en enkel tabell)';
 $strPDFReportTitle = 'Rapporttittel';
 $strPerHour = 'per time';
 $strPerMinute = 'per minutt';
@@ -598,6 +612,8 @@ $strPrivDescUpdate = 'Tillater endring av data.';
 $strPrivDescUsage = 'Ingen privilegier.';
 $strPrivileges = 'Privilegier';
 $strPrivilegesReloaded = 'Oppfriskingen av privilegiene lyktes.';
+$strProcedures = 'Prosedyrer';
+$strProcesses = 'Prosesser';
 $strProcesslist = 'Prosess liste';
 $strProtocolVersion = 'Protokollversjon';
 $strPutColNames = 'Sett inn feltnavn i første rad';
@@ -608,6 +624,7 @@ $strQBE = 'Spørring ved eksempel (Query by Example)';
 $strQueryCache = 'Spørringsmellomlager';
 $strQueryFrame = 'Spørringsvindu';
 $strQueryOnDb = 'SQL-spørring i database <b>%s</b>:';
+$strQueryResultsOperations = 'Spørringsresultatshandlinger';
 $strQuerySQLHistory = 'SQL-historie';
 $strQueryStatistics = '<b>Spørrings statistikk</b>: Siden oppstart, har %s spørringer blitt sendt til tjeneren.';
 $strQueryTime = 'Spørring tok %01.4f sek';
@@ -625,7 +642,7 @@ $strRelationsForTable = 'RELASJONER FOR TABELLEN';
 $strRelations = 'Relasjoner';
 $strRelationView = 'Relasjonsvisning';
 $strReloadingThePrivileges = 'Oppfrisker privilegiene';
-$strReloadMySQL = 'Omstart av MySQL';
+$strReloadPrivileges = 'Oppfrisk privilegier';
 $strRemoveSelectedUsers = 'Fjern valgte brukere';
 $strRenameDatabaseOK = 'Databasen %s har endret navn til %s';
 $strRenameTable = 'Endre tabellens navn';
@@ -684,7 +701,7 @@ $strServerNotResponding = 'Tjeneren svarer ikke';
 $strServerStatusDelayedInserts = 'Forsinkede innsettinger';
 $strServerStatus = 'Kjøringsinformasjon';
 $strServerStatusUptime = 'Denne MySQL tjeneren har kjørt i %s. Den startet opp den %s.';
-$strServerTabProcesslist = 'Prosesser';
+$strServers = 'Tjenere';
 $strServerTabVariables = 'Variabler';
 $strServer = 'Tjener';
 $strServerTrafficNotes = '<b>Tjenertraffikk</b>: Disse tabellene viser statistikk over nettverkstrafikken for denne MySQL-tjeneren siden dens oppstart.';
@@ -718,6 +735,8 @@ $strShowStatusHandler_discoverDescr = 'MySQL tjeneren kan spørre NDB Cluster la
 $strShowStatusHandler_read_firstDescr = 'Antall ganger det første innlegget ble lest fra en index. Hvis dette tallet er høyt tyder det på at tjeneren utfører en god del fullindekssøk; for eksempel, SELECT col1 FROM foo, da forutsatt at col1 er indeksert.';
 $strShowStatusHandler_read_keyDescr = 'Antall forespørsler for å lese en rad basert på en nøkkel. Hvis dette tallet er høyt gir dette en god indikasjon på at dine spørringer og tabeller er riktig indeksert.';
 $strShowStatusHandler_read_nextDescr = 'Antall forespørsler for å lese en rad basert på en fast posisjon. Denne er høy hvis du utører mange spørringer som behøver sortering av resultatet. Du har sansynligvis mange spørringer som krever at MySQL leser hele tabeller eller du har joins som ikke bruker nøkler korrekt.';
+$strShowStatusHandler_read_prevDescr = 'Antall forespørsler for å lese den forrige raden i nøkkelrekkefølge. Denne lesemetoden er hovedsakelig brukt for å optimalisere ORDER BY ... DESC.';
+$strShowStatusHandler_read_rndDescr = 'Antall forespørsler for å lese en rad basert på en fast posisjon. Denne er høy om du utfører mange spørringer som behøver sorteringer av resultatet. Du har mest sansynlig mange spørringer som krever at MySQL leser hele tabeller eller du har joins som som ikke bruker nøkler korrekt.';
 $strShowStatusHandler_read_rnd_nextDescr = 'Antall forespørsler for å lese neste rad i datafila. Dette tallet er høyt hvis du utfører mange tabellskanninger. Vanligvis betyr dette at dine tabeller ikke er rett indeksert eller at dine spørringer ikke er skrevet for å utnytte de indeksene du har.';
 $strShowStatusHandler_rollbackDescr = 'Antall interne ROLLBACK kommandoer.';
 $strShowStatusHandler_updateDescr = 'Antall forespørsler for å oppdatere en rad i en tabell.';
@@ -825,7 +844,7 @@ $strSort = 'Sorter';
 $strSpaceUsage = 'Plassbruk';
 $strSpanish = 'Spansk';
 $strSplitWordsWithSpace = 'Ord er separert med et mellomrom (" ").';
-$strSQLExportCompatibility = 'SQL eksportkompabilitet';
+$strSQLCompatibility = 'SQL kompatibilitetsmodus';
 $strSQLExportType = 'Eksporttype';
 $strSQLImportOptions = 'SQL innstillinger';
 $strSQLOptions = 'SQL valg';
@@ -847,8 +866,8 @@ $strStorageEngine = 'Lagringsmotor';
 $strStorageEngines = 'Lagringsmotorer';
 $strStrucCSV = 'CSV-data';
 $strStrucData = 'Struktur og data';
-$strStrucDrop = 'Legg til DROP TABLE';
 $strStrucExcelCSV = 'CSV for MS Excel data';
+$strStrucNativeExcelOptions = 'Excel eksportinnstillinger';
 $strStrucNativeExcel = 'Originale MS Excel data';
 $strStrucOnly = 'Kun struktur';
 $strStructPropose = 'Foreslå tabellstruktur';
@@ -872,7 +891,6 @@ $strTableOptions = 'Tabellinnstillinger';
 $strTables = '%s tabell(er)';
 $strTableStructure = 'Tabellstruktur for tabell';
 $strTable = 'Tabell';
-$strTableType = 'Tabelltype';
 $strTakeIt = 'velg';
 $strTblPrivileges = 'Tabell-spesifikke privilegier';
 $strTempData = 'Midlertidige data';
@@ -900,7 +918,7 @@ $strTraditionalSpanish = 'Tradisjonell spansk';
 $strTraffic = 'Trafikk';
 $strTransactionCoordinator = 'Transaksjonskoordinator';
 $strTransformation_application_octetstream__download = 'Vis en link for å kunne laste ned de binære dataene til et felt. Den første opsjonen er filnavnet til den binære fila. Den andre opsjonen er et potensielt feltnavn i en tabell som inneholder filnavnet. Hvis du velger den andre opsjonen så må den første være satt til en tom strengverdi';
-$strTransformation_application_octetstream__hex = 'Vis dataene i heksadesimal.';
+$strTransformation_application_octetstream__hex ='Vis dataene i heksadesimal. Den valgfrie første parameteren tilkjennegir hvor ofte mellomrom vil bli lagt til (standard hvert andre tegn).';
 $strTransformation_image_jpeg__inline = 'Viser et klikkbart tommelfingerbilde; valg: bredde, høyde i piksler (bevarer originale forhold)';
 $strTransformation_image_jpeg__link = 'Viser en link til dette bildet (m.a.o. direkte blob-nedlasting).';
 $strTransformation_image_png__inline = 'Se image/jpeg: inline';
@@ -928,6 +946,7 @@ $strUpdateQuery = 'Oppdater spørring';
 $strUpdComTab = 'Les i dokumentasjonen hvordan du oppdaterer din Column_comments tabell';
 $strUpgrade = 'Du burde oppgradere til %s %s eller nyere.';
 $strUploadLimit = 'Du forsøkte sansynligvis å laste opp en for stor fil. Sjekk %sdokumentasjonen%s for måter å omgå denne begrensningen.';
+$strUploadsNotAllowed = 'Filopplastinger er ikke tillatt på denne tjeneren.';
 $strUsage = 'Bruk';
 $strUseBackquotes = 'Bruk venstre anførselstegn med tabell og feltnavn';
 $strUsedPhpExtensions = 'Brukte PHP-tillegg';
@@ -969,6 +988,7 @@ $strWritingCommentNotPossible = 'Skriving av kommentar er ikke mulig';
 $strWritingRelationNotPossible = 'Skriving av relasjon er ikke mulig';
 $strWrongUser = 'Ugyldig brukernavn/passord. Ingen tilgang.';
 
+$strXMLOptions = 'XML innstillinger';
 $strXML = 'XML';
 
 $strYes = 'Ja';
@@ -976,9 +996,4 @@ $strYes = 'Ja';
 $strZeroRemovesTheLimit = 'Merk: Ved å sette disse til 0 (null) fjernes begrensningen.';
 $strZip = 'Komprimert (zip)';
 
-// To translate:
-
-$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.'; //to translate
-$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.'; //to translate
-
 ?>
